==> diamond-shop-v1.3.50-043668.zip: src/DTO/BasketItemRequest.php <==
<?

namespace Shop\DTO;

/**
 * Для создания
 *
 * @author Admin
 */
class BasketItemRequest
{

    protected $price;
    protected $amount;
    protected $name;
    protected $article;
    protected $desc;
    protected $ref;
    protected $brand;
    protected $shop;
    protected $menagerComment;

    function getMenagerComment()
    {
        return $this->menagerComment;
    }

    function setMenagerComment($menagerComment)
    {
        $this->menagerComment = $menagerComment;
        return $this;
    }

    function getShop()
    {
        return $this->shop;
    }

    function setShop($shop)
    {
        $this->shop = $shop;
        return $this;
    }

    function getBrand()
    {
        return $this->brand;
    }

    function setBrand($brand)
    {
        $this->brand = $brand;
        return $this;
    }

    function getRef()
    {
        return $this->ref;
    }

    function setRef($ref)
    {
        $this->ref = $ref;
        return $this;
    }

    function getPrice()
    {
        return $this->price;
    }

    function getAmount()
    {
        return $this->amount;
    }

    function getName()
    {
        return $this->name;
    }

    function getArtice()
    {
        return $this->article;
    }

    function getDesc()
    {
        return $this->desc;
    }

    function setPrice($price)
    {
        $this->price = $price;
        return $this;
    }

    function setAmount($amount)
    {
        $this->amount = $amount;
        return $this;
    }

    function setName($name)
    {
        $this->name = $name;
        return $this;
    }

    function setArticle($article)
    {
        $this->article = $article;
        return $this;
    }

    function setDesc($desc)
    {
        $this->desc = $desc;
        return $this;
    }

}

==> diamond-shop-v1.4.14-99a1b7.zip: src/DTO/BasketItemRequest.php <==
<?

namespace Shop\DTO;

/**
 * Для создания
 *
 * @author Admin
 */
class BasketItemRequest
{

    protected $price;
    protected $amount;
    protected $name;
    protected $article;
    protected $desc;
    protected $ref;
    protected $brand;
    protected $shop;
    protected $menagerComment;
    /**
     * @var string
     */
    protected $destination;

    /**
     * @return string
     */
    public function getDestination(): ?string
    {
        return $this->destination;
    }

    /**
     * @param string $destination
     * @return BasketItemRequest
     */
    public function setDestination(?string $destination): BasketItemRequest
    {
        $this->destination = $destination;
        return $this;
    }


    function getMenagerComment()
    {
        return $this->menagerComment;
    }

    function setMenagerComment($menagerComment)
    {
        $this->menagerComment = $menagerComment;
        return $this;
    }

    function getShop()
    {
        return $this->shop;
    }

    function setShop($shop)
    {
        $this->shop = $shop;
        return $this;
    }

    function getBrand()
    {
        return $this->brand;
    }

    function setBrand($brand)
    {
        $this->brand = $brand;
        return $this;
    }

    function getRef()
    {
        return $this->ref;
    }

    function setRef($ref)
    {
        $this->ref = $ref;
        return $this;
    }

    function getPrice()
    {
        return $this->price;
    }

    function getAmount()
    {
        return $this->amount;
    }

    function getName()
    {
        return $this->name;
    }

    function getArtice()
    {
        return $this->article;
    }

    function getDesc()
    {
        return $this->desc;
    }

    function setPrice($price)
    {
        $this->price = $price;
        return $this;
    }

    function setAmount($amount)
    {
        $this->amount = $amount;
        return $this;
    }

    function setName($name)
    {
        $this->name = $name;
        return $this;
    }

    function setArticle($article)
    {
        $this->article = $article;
        return $this;
    }

    function setDesc($desc)
    {
        $this->desc = $desc;
        return $this;
    }

}
